@@ -91,7 +91,12 @@ function export_env_vars
  	fi
 	
 	echo "using pgpool-II at "$PGPOOL_PATH
+
+	export PGPOOL_VERSION=`$PGPOOL_PATH/bin/pgpool --version 2>&1`
+
 	export PGPOOL_INSTALL_DIR=$PGPOOL_PATH
+	# where to look for pgpool.conf.sample files.
+	export PGPOOLDIR=$PGPOOL_INSTALL_DIR/etc
 
 	PGPOOLLIB=${PGPOOL_INSTALL_DIR}/lib
 	if [ -z "$LD_LIBRARY_PATH" ];then
@@ -111,12 +116,12 @@ function export_env_vars
 function print_info
 {
 	echo ${CBLUE}"*************************"${CNORM}
-
-	echo "REGRESSION MODE : "${CBLUE}$MODE${CNORM}
-	echo "PGPOOL-II       : "${CBLUE}$PGPOOL_PATH${CNORM}
-	echo "PostgreSQL bin  : "${CBLUE}$PGBIN${CNORM}
-	echo "pgbench         : "${CBLUE}$PGBENCH_PATH${CNORM}
-	echo "PostgreSQL jdbc : "${CBLUE}$JDBC_DRIVER${CNORM}
+	echo "REGRESSION MODE          : "${CBLUE}$MODE${CNORM}
+	echo "Pgpool-II version        : "${CBLUE}$PGPOOL_VERSION${CNORM}
+	echo "Pgpool-II install path   : "${CBLUE}$PGPOOL_PATH${CNORM}
+	echo "PostgreSQL bin           : "${CBLUE}$PGBIN${CNORM}
+	echo "pgbench                  : "${CBLUE}$PGBENCH_PATH${CNORM}
+	echo "PostgreSQL jdbc          : "${CBLUE}$JDBC_DRIVER${CNORM}
 	echo ${CBLUE}"*************************"${CNORM}
 }
 
